/*
*****************************************************************************
* Copyright by ams AG                                                       *
* All rights are reserved.                                                  *
*                                                                           *
* IMPORTANT - PLEASE READ CAREFULLY BEFORE COPYING, INSTALLING OR USING     *
* THE SOFTWARE.                                                             *
*                                                                           *
* THIS SOFTWARE IS PROVIDED FOR USE ONLY IN CONJUNCTION WITH AMS PRODUCTS.  *
* USE OF THE SOFTWARE IN CONJUNCTION WITH NON-AMS-PRODUCTS IS EXPLICITLY    *
* EXCLUDED.                                                                 *
*                                                                           *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS       *
* "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT         *
* LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS         *
* FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT  *
* OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,     *
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT          *
* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,     *
* DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY     *
* THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT       *
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE     *
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.      *
*****************************************************************************
*/

#ifndef __AMS_LINUX_I2C_H
#define __AMS_LINUX_I2C_H

#include <stdint.h>

/**
 * @brief
 *      write data block to I2C device
 * @param[in] slave_addr
 *      i2c salve address
 * @param[in] reg
 *      starting register address
 * @param[in] buf
 *      pointer to data block
 * @param[in] len
 *      number of bytes to write
 * @return
 *      -1 : failed;  0 : success
 */
int32_t write_i2c_block(uint32_t slave_addr, uint8_t reg, const uint8_t *buf, uint32_t len);

/**
 * @brief
 *      read data block from I2C device
 * @param[in] slave_addr
 *      i2c salve address
 * @param[in] reg
 *      starting register address
 * @param[in] buf
 *      pointer to data buffer that are read from device
 * @param[in] len
 *      number of bytes to read
 * @return
 *      -1 : failed;  0 : success
 */
int32_t read_i2c_block(uint32_t slave_addr, uint8_t reg, uint8_t *buf, uint32_t len);

#endif
